==> haskell-coinbase-pro-0.9.3.2-423-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-coinbase-pro.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 coinbase-pro
version:              0.9.3.2
visibility:           public
id:                   coinbase-pro-0.9.3.2-A6YY7kbBrwAGQUP6H0W3KD
key:                  coinbase-pro-0.9.3.2-A6YY7kbBrwAGQUP6H0W3KD
license:              MIT
copyright:            2022 Michael Dunn <michaelsdunn1@gmail.com>
maintainer:           Michael Dunn <michaelsdunn1@gmail.com>
author:               Michael Dunn <michaelsdunn1@gmail.com>
homepage:             https://github.com/mdunnio/coinbase-pro#readme
synopsis:             Client for Coinbase Pro
description:          Client for Coinbase Pro REST and Websocket APIs
category:             Web, Finance
abi:                  d20b8acfa0273a4cb67d316ab54ed05c
exposed:              True
exposed-modules:
    CoinbasePro.Authenticated CoinbasePro.Authenticated.API
    CoinbasePro.Authenticated.Accounts
    CoinbasePro.Authenticated.CoinbaseAccounts
    CoinbasePro.Authenticated.Conversion
    CoinbasePro.Authenticated.Deposit CoinbasePro.Authenticated.Fills
    CoinbasePro.Authenticated.Headers CoinbasePro.Authenticated.Limits
    CoinbasePro.Authenticated.Oracle CoinbasePro.Authenticated.Orders
    CoinbasePro.Authenticated.Payment CoinbasePro.Authenticated.Profile
    CoinbasePro.Authenticated.Report CoinbasePro.Authenticated.Request
    CoinbasePro.Authenticated.Transfer
    CoinbasePro.Authenticated.Withdrawal CoinbasePro.Environment
    CoinbasePro.Headers CoinbasePro.MarketData.AggregateOrderBook
    CoinbasePro.MarketData.FullOrderBook CoinbasePro.MarketData.Types
    CoinbasePro.Request CoinbasePro.Types CoinbasePro.Unauthenticated
    CoinbasePro.Unauthenticated.API CoinbasePro.WebSocketFeed
    CoinbasePro.WebSocketFeed.Channel
    CoinbasePro.WebSocketFeed.Channel.Full.Activate
    CoinbasePro.WebSocketFeed.Channel.Full.Change
    CoinbasePro.WebSocketFeed.Channel.Full.Done
    CoinbasePro.WebSocketFeed.Channel.Full.Match
    CoinbasePro.WebSocketFeed.Channel.Full.Open
    CoinbasePro.WebSocketFeed.Channel.Full.Received
    CoinbasePro.WebSocketFeed.Channel.Heartbeat
    CoinbasePro.WebSocketFeed.Channel.Level2
    CoinbasePro.WebSocketFeed.Channel.Status
    CoinbasePro.WebSocketFeed.Channel.Ticker
    CoinbasePro.WebSocketFeed.Request
    CoinbasePro.WebSocketFeed.Response

hidden-modules:       Paths_coinbase_pro
import-dirs:          /usr/lib/ghc-9.6.6/site-local/coinbase-pro-0.9.3.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/coinbase-pro-0.9.3.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/coinbase-pro-0.9.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-coinbase-pro
hs-libraries:         HScoinbase-pro-0.9.3.2-A6YY7kbBrwAGQUP6H0W3KD
depends:
    HsOpenSSL-0.11.7.9-96EVs0QSsusKamWieCsd7F
    aeson-2.1.2.1-GojnAvr1Jep10WUNi5H1Pi
    aeson-casing-0.2.0.0-AslSveij60I8Gr7VRX3X2y
    async-2.2.5-1Z88VuXAsSjFYCStMD3XFv base-4.18.2.1 binary-0.8.9.1
    bytestring-0.11.5.3 containers-0.6.7
    cryptonite-0.30-LM2EJiGJsV242NzdXbkugt exceptions-0.10.7
    http-api-data-0.6.1-5XEHPNAfLnyD0ajpwpE9eT
    http-client-0.7.19-76DosIrYZ8GJOiYGyhGmc9
    http-client-tls-0.3.6.4-J61axw4VOrbKDwJUgwBVs6
    http-streams-0.8.9.9-ABMDFuwUznfG2JgvedPSi7
    http-types-0.12.4-AM56akyPNdKBTyuGfrlHOS
    io-streams-1.5.2.2-GBIxq3Y3ahG4K7ipZI07Kf
    memory-0.18.0-6zo36PbRecTK4fqbBnx0f5
    network-3.1.4.0-8n0F06kM1hW6KWRJNaBKOe
    servant-0.20.3.0-FMI4LG4x1t4Dir4ovtxFzm
    servant-client-0.20.3.0-FWrlmoCIyRJ3QI0iq54aUU
    servant-client-core-0.20.3.0-9piRNUKE2ioC3q9igytHDR
    tasty-1.5.2-K3PchMZYxV2JdxeMIpuhjP
    tasty-hunit-0.10.2-2LR7aB9N8B7BXZbrMOVMFb text-2.0.2 time-1.12.2
    transformers-0.6.1.0 unagi-streams-0.2.7-KCaD7zOYOgkFWVaPiTOr0I
    unordered-containers-0.2.20.1-50qrTxmoJy9AxZ7OdMnycu
    uuid-1.3.16-GebAPnJBeXo3Et5zvwjxGZ
    vector-0.13.2.0-L5lYsWFgdBEAgjlr9nnpMP
    websockets-0.12.7.3-JW0Ikw2TM82FNqIPUUjbme
    wuss-2.0.1.6-Cy5WOXNLVCAL4i8IUou5b2

haddock-interfaces:
    /usr/share/doc/haskell-coinbase-pro/html/coinbase-pro.haddock

haddock-html:         /usr/share/doc/haskell-coinbase-pro/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-coinbase-pro-0.9.3.2-424-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-coinbase-pro.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 coinbase-pro
version:              0.9.3.2
visibility:           public
id:                   coinbase-pro-0.9.3.2-CGwAtyWFwOyFRGGLEZLKp6
key:                  coinbase-pro-0.9.3.2-CGwAtyWFwOyFRGGLEZLKp6
license:              MIT
copyright:            2022 Michael Dunn <michaelsdunn1@gmail.com>
maintainer:           Michael Dunn <michaelsdunn1@gmail.com>
author:               Michael Dunn <michaelsdunn1@gmail.com>
homepage:             https://github.com/mdunnio/coinbase-pro#readme
synopsis:             Client for Coinbase Pro
description:          Client for Coinbase Pro REST and Websocket APIs
category:             Web, Finance
abi:                  2b01d4054dd336f27e0123ac2e78eafa
exposed:              True
exposed-modules:
    CoinbasePro.Authenticated CoinbasePro.Authenticated.API
    CoinbasePro.Authenticated.Accounts
    CoinbasePro.Authenticated.CoinbaseAccounts
    CoinbasePro.Authenticated.Conversion
    CoinbasePro.Authenticated.Deposit CoinbasePro.Authenticated.Fills
    CoinbasePro.Authenticated.Headers CoinbasePro.Authenticated.Limits
    CoinbasePro.Authenticated.Oracle CoinbasePro.Authenticated.Orders
    CoinbasePro.Authenticated.Payment CoinbasePro.Authenticated.Profile
    CoinbasePro.Authenticated.Report CoinbasePro.Authenticated.Request
    CoinbasePro.Authenticated.Transfer
    CoinbasePro.Authenticated.Withdrawal CoinbasePro.Environment
    CoinbasePro.Headers CoinbasePro.MarketData.AggregateOrderBook
    CoinbasePro.MarketData.FullOrderBook CoinbasePro.MarketData.Types
    CoinbasePro.Request CoinbasePro.Types CoinbasePro.Unauthenticated
    CoinbasePro.Unauthenticated.API CoinbasePro.WebSocketFeed
    CoinbasePro.WebSocketFeed.Channel
    CoinbasePro.WebSocketFeed.Channel.Full.Activate
    CoinbasePro.WebSocketFeed.Channel.Full.Change
    CoinbasePro.WebSocketFeed.Channel.Full.Done
    CoinbasePro.WebSocketFeed.Channel.Full.Match
    CoinbasePro.WebSocketFeed.Channel.Full.Open
    CoinbasePro.WebSocketFeed.Channel.Full.Received
    CoinbasePro.WebSocketFeed.Channel.Heartbeat
    CoinbasePro.WebSocketFeed.Channel.Level2
    CoinbasePro.WebSocketFeed.Channel.Status
    CoinbasePro.WebSocketFeed.Channel.Ticker
    CoinbasePro.WebSocketFeed.Request
    CoinbasePro.WebSocketFeed.Response

hidden-modules:       Paths_coinbase_pro
import-dirs:          /usr/lib/ghc-9.6.6/site-local/coinbase-pro-0.9.3.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/coinbase-pro-0.9.3.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/coinbase-pro-0.9.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-coinbase-pro
hs-libraries:         HScoinbase-pro-0.9.3.2-CGwAtyWFwOyFRGGLEZLKp6
depends:
    HsOpenSSL-0.11.7.9-96EVs0QSsusKamWieCsd7F
    aeson-2.1.2.1-GojnAvr1Jep10WUNi5H1Pi
    aeson-casing-0.2.0.0-AslSveij60I8Gr7VRX3X2y
    async-2.2.5-1Z88VuXAsSjFYCStMD3XFv base-4.18.2.1 binary-0.8.9.1
    bytestring-0.11.5.3 containers-0.6.7
    cryptonite-0.30-LM2EJiGJsV242NzdXbkugt exceptions-0.10.7
    http-api-data-0.6.1-5XEHPNAfLnyD0ajpwpE9eT
    http-client-0.7.19-ITPZXASBEGHLmOi4NfdGY8
    http-client-tls-0.3.6.4-2TpGPIcpPZAJDvilQsJ18b
    http-streams-0.8.9.9-ABMDFuwUznfG2JgvedPSi7
    http-types-0.12.4-AM56akyPNdKBTyuGfrlHOS
    io-streams-1.5.2.2-GBIxq3Y3ahG4K7ipZI07Kf
    memory-0.18.0-6zo36PbRecTK4fqbBnx0f5
    network-3.1.4.0-8n0F06kM1hW6KWRJNaBKOe
    servant-0.20.3.0-FMI4LG4x1t4Dir4ovtxFzm
    servant-client-0.20.3.0-4oEbmWCYhwn8ZD2C1b9D6B
    servant-client-core-0.20.3.0-9piRNUKE2ioC3q9igytHDR
    tasty-1.5.2-K3PchMZYxV2JdxeMIpuhjP
    tasty-hunit-0.10.2-2LR7aB9N8B7BXZbrMOVMFb text-2.0.2 time-1.12.2
    transformers-0.6.1.0 unagi-streams-0.2.7-KCaD7zOYOgkFWVaPiTOr0I
    unordered-containers-0.2.20.1-50qrTxmoJy9AxZ7OdMnycu
    uuid-1.3.16-GebAPnJBeXo3Et5zvwjxGZ
    vector-0.13.2.0-L5lYsWFgdBEAgjlr9nnpMP
    websockets-0.12.7.3-AhAyzDPktssBd5IasgBMf7
    wuss-2.0.1.6-1YU4jDyDl5DzKhlT8zjd1

haddock-interfaces:
    /usr/share/doc/haskell-coinbase-pro/html/coinbase-pro.haddock

haddock-html:         /usr/share/doc/haskell-coinbase-pro/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
